'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _semver = require('semver');

var _semver2 = _interopRequireDefault(_semver);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var types = {
  major: 'major',
  minor: 'minor',
  patch: 'patch',
  pre: 'pre',
  promote: 'promote'
};

exports.default = function (current, type, options) {
  options = options || {};
  var isPreRelease = current.indexOf('-') > 0;

  if (!isPreRelease && type === types.pre) {
    throw new Error('Cannot bump pre-release while stable');
  }

  if (type === types.promote) {
    if (!isPreRelease) {
      throw new Error('Cannot promote already stable version');
    }
    return current.replace(/\-.+/, '');
  }

  var increment = figureIncrement(isPreRelease, type, options.stable);
  var newVersion = _semver2.default.inc(current, increment);
  return fixPreReleaseIdentifier(newVersion, options.tag);
};

var figureIncrement = function figureIncrement(isPreRelease, type, toStable) {
  if (isPreRelease && !toStable) {
    switch (type) {
      case types.major:
        return 'premajor';
      case types.minor:
        return 'preminor';
      case types.patch:
        return 'prepatch';
      default:
        return 'prerelease';
    }
  } else if (!toStable) {
    switch (type) {
      case types.major:
        return 'premajor';
      case types.minor:
        return 'preminor';
      default:
        return 'prepatch';
    }
  } else {
    switch (type) {
      case types.major:
        return 'major';
      case types.minor:
        return 'minor';
      default:
        return 'patch';
    }
  }
};

var fixPreReleaseIdentifier = function fixPreReleaseIdentifier(version, tag) {
  if (tag) {
    if (/\-\w+/.test(version)) {
      version = version.replace(/\-.+/, '-' + tag);
    } else {
      version = version + ('-' + tag);
    }
  }

  return version.replace(/\-0$/, '-' + (tag || 'beta'));
};