'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

var _readlineSync = require('readline-sync');

var _readlineSync2 = _interopRequireDefault(_readlineSync);

var _bump = require('./bump');

var _bump2 = _interopRequireDefault(_bump);

var _exec = require('./exec');

var _exec2 = _interopRequireDefault(_exec);

var _logger = require('./logger');

var _logger2 = _interopRequireDefault(_logger);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var confirm = function confirm(question, options) {
  if (options.unattended) {
    return true;
  }
  process.stdout.write(_chalk2.default.green('yag') + ': ');
  return !_readlineSync2.default.keyInYN(question);
};

exports.default = function (type, options) {
  var packagePath = findPackageJson();
  var oldPackageFile = _fs2.default.readFileSync(packagePath, 'utf8');
  var pkg = JSON.parse(oldPackageFile);
  var currentVersion = pkg.version;
  var newVersion = (0, _bump2.default)(currentVersion, type, options);
  _logger2.default.info('Bumping from ' + hightlight(currentVersion) + ' to ' + hightlight(newVersion));

  if (confirm('Patch package.json file?', options)) {
    _logger2.default.info('Aborting...');
    return 0;
  }

  _logger2.default.info('Patching ' + _chalk2.default.cyan('package.json') + ' with version ' + _chalk2.default.cyan(newVersion));
  pkg.version = newVersion;
  _fs2.default.writeFileSync(packagePath, JSON.stringify(pkg, null, 2));

  if (confirm('Commit changes and apply tag?', options)) {
    _logger2.default.info('Aborting...');
    _fs2.default.writeFileSync(packagePath, oldPackageFile);
    return 0;
  }

  var tagName = 'v' + newVersion;

  (0, _exec2.default)('git add ' + _path2.default.relative('', packagePath));
  (0, _exec2.default)('git commit -m "Release ' + tagName + '"');
  (0, _exec2.default)('git tag ' + tagName + ' -a -m "Release ' + tagName + '"');

  if (confirm('Publish new tag?', options)) {
    _logger2.default.info('Aborting...');
    (0, _exec2.default)('git reset HEAD~1 --mixed');
    (0, _exec2.default)('git tag -d ' + tagName);
    _fs2.default.writeFileSync(packagePath, oldPackageFile);
    return 0;
  }

  (0, _exec2.default)('git push origin master ' + tagName);
};

var hightlight = _chalk2.default.yellow.inverse;

var findPackageJson = function findPackageJson() {
  var currentPath = '';
  var lastChecked = void 0;
  while (true) {
    var pathToCheck = _path2.default.resolve(currentPath, 'package.json');
    if (pathToCheck === lastChecked) {
      throw new Error('package.json file is inaccessible or doesn\'t exist');
    }
    lastChecked = pathToCheck;

    try {
      _fs2.default.accessSync(pathToCheck, _fs2.default.R_OK | _fs2.default.W_OK);
      return pathToCheck;
    } catch (err) {
      currentPath += '../';
    }
  }
};